@@ -10,18 +10,21 @@ use Psr\Http\Message\ServerRequestInterface;
 
 final readonly class SuppliedCronKeyFromHeader implements SuppliedCronKeyGetter
 {
-    private const HEADER__CRON_KEY = 'X-Newton-Cron-Key';
+
+    public function __construct(private CronConfig $config)
+    {
+    }
 
     /**
      * @throws CronKeyException
      */
     public function get(ServerRequestInterface $request): string
     {
-        if (!$request->hasHeader(self::HEADER__CRON_KEY)) {
+        if (!$request->hasHeader($this->config->header)) {
             throw new CronKeyException('No cron key present', 422);
         }
 
-        $supplied = $request->getHeader(self::HEADER__CRON_KEY)[0];
+        $supplied = $request->getHeader($this->config->header)[0];
 
         if (empty($supplied)) {
             throw new CronKeyException('Cron key empty', 422);
